#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-HvZwT1hX8b7HQ3Y6YTWN9p
key:                  haskell-language-server-2.3.0.0-HvZwT1hX8b7HQ3Y6YTWN9p
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  56612d32da0e87e5ba7393585a6925fb
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-HvZwT1hX8b7HQ3Y6YTWN9p
depends:
    aeson-pretty-0.8.11-BqVhnnBaupkIjWZ0yhugs4
    async-2.2.6-5xQ7XDEe3v3DeLHeJRStgT base-4.18.2.1
    base16-bytestring-1.0.2.0-K0QjIJ8Wcv0Kwq3shHOJke
    bytestring-0.11.5.3 containers-0.6.7
    cryptohash-sha1-0.11.101.0-8m6dGgvWIl487ZX14guT6L
    data-default-0.7.1.3-CRQVneoi5B7He0Tx6HSYSU directory-1.3.8.5
    extra-1.7.16-92gEBqN3yIpF5We3DBC4D filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-LSl1l3dLISv8h9fG2nlQGh
    githash-0.1.7.0-5jQGNbKJ7HZLRYuv3bHDwv
    hie-bios-0.12.0-KmmHC0wYatlEG4eaojg8Dz
    hiedb-0.4.3.0-27bJatdPLn98DjsOqTKP1s
    hls-alternate-number-format-plugin-2.3.0.0-E7fwvnx7KUp9c4cS64a4Zx
    hls-cabal-fmt-plugin-2.3.0.0-Kim6fKgpjLl9HKCUwK3pEx
    hls-cabal-plugin-2.3.0.0-5Gk7l8F8ehjIcg9eVOYTbA
    hls-call-hierarchy-plugin-2.3.0.0-34ew6ORqIqLKsT6fznCGoN
    hls-change-type-signature-plugin-2.3.0.0-8NzRhr5kt1L7mtxsDLRjtV
    hls-class-plugin-2.3.0.0-KIeJywLLTyv6hsliFzyLuI
    hls-code-range-plugin-2.3.0.0-3UAgfLIhqc5Do4iq4kQ9he
    hls-eval-plugin-2.3.0.0-6goEek4d3Tg9c8w63pa5df
    hls-explicit-fixity-plugin-2.3.0.0-KdWDTAnUknZEc3xadsdijR
    hls-explicit-imports-plugin-2.3.0.0-DUDS28Zy1Ps76kFAVmgapx
    hls-explicit-record-fields-plugin-2.3.0.0-2UM3zCusqDOLtp5zJB59yb
    hls-fourmolu-plugin-2.3.0.0-Bu3ifn59s2KHHvYTLkSI5f
    hls-gadt-plugin-2.3.0.0-3RhMLBjhBwjGRWx9f65FK1
    hls-graph-2.3.0.0-7rqFDxJmnlX17sL7WxQyZd
    hls-hlint-plugin-2.3.0.0-EbNAFp7gKSUAVIrtrOoW3d
    hls-module-name-plugin-2.3.0.0-CCvytEwove3ijW4oVQKco
    hls-ormolu-plugin-2.3.0.0-Kz1ReuNLGEE5RHkdhVjEJP
    hls-overloaded-record-dot-plugin-2.3.0.0-FJhW5mX3OiC1BFLKYEmL56
    hls-plugin-api-2.3.0.0-FhaU59j0XGvCTH6JIAhfdo
    hls-pragmas-plugin-2.3.0.0-8tU4BM7fQhIClTr4RV5THD
    hls-qualify-imported-names-plugin-2.3.0.0-LuCVQbPbPm96CK0fUdw05n
    hls-refactor-plugin-2.3.0.0-En9pIYCXVba6f3Eyk3syu8
    hls-rename-plugin-2.3.0.0-5zzQZPUWzbK8xL33dcSTzE
    hls-retrie-plugin-2.3.0.0-L1VldCcq7yzFFyudHJxYhd
    hls-splice-plugin-2.3.0.0-5v4k8ibsVl8IgasP1KbtAj
    hls-stylish-haskell-plugin-2.3.0.0-GkzrNllN1aoKsKYf27WQ1H
    lsp-2.2.0.0-8keiVbyHMomIz2bmB3Jsqn
    optparse-applicative-0.18.1.0-6cREMRvcEOW6x5IeiCw6lt
    optparse-simple-0.1.1.4-2gDw8XU3hReLiQdTEBWCSu
    prettyprinter-1.7.1-4EZkWc5tq0yFCEPbAPD9Qw process-1.6.19.0
    safe-exceptions-0.1.7.4-J6rtfAXDyMB77zQjT5hSt
    sqlite-simple-0.4.19.0-JpJKljS6mH5IjQsH4x3dy9 text-2.0.2
    unordered-containers-0.2.20.1-4LGdNZVNGNC9SVCFAuU8Mp

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

